<?php
/*

	 	    WWW L-System Explorer
      (c) 2006 Mr. Zdeeck <zdeeck@borg.cz> / Borg Solutions
	 <http://zdeeck.borg.cz/programming/wlse.html>

This code is presented under GNU GPL. See file COPYING for more info.

*/

include("turtle.php");

// Set up variables
$w=$_REQUEST["w"];
$h=$_REQUEST["h"];
$x=$_REQUEST["x"];
$y=$_REQUEST["y"];

$iter=$_REQUEST["iter"];
if ($iter+0>10)
    $iter=10;
if ($iter+0<0)
    $iter=0;
$iter++;

$bgcol=$_REQUEST["bgcol"];
$pencol1=$_REQUEST["pencol1"];
$pencol2=$_REQUEST["pencol2"];
$dotcol=$_REQUEST["dotcol"];
$s_step=$_REQUEST["s_step"];
$s_angle=$_REQUEST["s_angle"];
$d_step=$_REQUEST["d_step"];
$d_angle=$_REQUEST["d_angle"];
$root=stripslashes($_REQUEST["root"]);
$rules=stripslashes($_REQUEST["rules"]);

if (!$debug)
    header("Content-type: image/png");

$im=imagecreate($w,$h);

function ParseColor ($col)
{
    if (substr($col,0,1)=="#")
	$col=substr($col,1);	

    $ret["hex"]=$col;
    $ret["r"]=hexdec(substr($col,0,2));
    $ret["g"]=hexdec(substr($col,2,2));
    $ret["b"]=hexdec(substr($col,4,2));
    return($ret);
}

// Allocate colors
$bgcol  =ParseColor($bgcol);
$pencol1=ParseColor($pencol1);
$pencol2=ParseColor($pencol2);
$dotcol =ParseColor($dotcol);

$background=imagecolorallocate($im,$bgcol["r"],$bgcol["g"],$bgcol["b"]);
$dotcol = imagecolorallocate($im,$dotcol["r"],$dotcol["g"],$dotcol["b"]);

// Interpolate colors
$r_d=($pencol2["r"]-$pencol1["r"])/$iter;
$g_d=($pencol2["g"]-$pencol1["g"])/$iter;
$b_d=($pencol2["b"]-$pencol1["b"])/$iter;

for ($i=0; $i <= $iter; $i++)
    $pencol[$i]=imagecolorallocate($im,$pencol1["r"]+($i*$r_d),$pencol1["g"]+($i*$g_d),$pencol1["b"]+($i*$b_d));

// Initialize Turtle
$turtle = new Turtle ($im,$x,$y,$debug);

// Convert variables
$d_step=(100-$d_step)/100;
$d_angle=(100-$d_angle)/100;
$root=stripslashes($root);
$rules=stripslashes($rules);
$string=$root;

// Prepare rule field
$begstr=$root.$rules;
for ($i=0; $i < strlen($begstr); $i++) {
    $char=substr($begstr,$i,1);
    if ($char!="=" && $char!=";")
	$rule[$char]=$char;
}

// Parse rules
$rlz=explode(";",$rules);
while ($rlzx = each ($rlz)) {
    $rlzx2=explode("=",trim($rlzx["value"]));
    if (trim($rlzx2[0])!="") {
	$rule[trim($rlzx2[0])]=trim($rlzx2[1]);
    }    
}

// Iterate rules
for ($i=1; $i < $iter; $i++) {
    $newstring="";
    for ($j=0; $j < strlen($string); $j++)
	$newstring.=$rule[substr($string,$j,1)];

    $string=$newstring;

    if ($debug)
	imagestring($im, 1, 9, 9*$i, $string, $pencol[0]);
}

$turtle->dotcolor=$dotcol;
$deep=0;
for ( $i=0; $i < strlen($string); $i++) {
    $comm=substr($string,$i,1);

    // Iteration deepness check
    if ($deep<0)
	$deep=0;

    if ($deep > $iter)
	$ci=$iter;
    else
	$ci=$deep;

    $step=pow($d_step,$deep)*$s_step;
    $angle=pow($d_angle,$deep)*$s_angle;

    $turtle->color=$pencol[$ci];

    if ($debug) {
	echo "STEP: ".$step." ".pow($d_step,$deep)."<br>";
	echo "ANGLE: ".$angle."<br>";
    }

    switch ($comm) {
	case "F":	// Forward
	    $turtle->Move($step);
	break;

	case "B":	// Backward
	    $turtle->Move(-$step);
	break;

	case "f":	// Half Forward
	    $turtle->Move($step/2);
	break;

	case "b":	// Half Backward
	    $turtle->Move(-$step/2);
	break;

	case "R":	// Random forward
	    $turtle->Move(rand(0,$step));
	break;

	case "r":	// Random half forward
	    $turtle->Move(rand(0,$step)/2);
	break;

	case "+":	// Rotate Clockwise
	    $turtle->Rotate($angle);
	break;

	case "-":	// Rotate Anticlockwise
	    $turtle->Rotate(-$angle);
	break;

	case "/":	// Rotate Half Clockwise
	    $turtle->Rotate($angle/2);
	break;

	case "\\":	// Rotate Half Anticlockwise
	    $turtle->Rotate(-$angle/2);
	break;

	case "^":	// Pen up
	    $turtle->PenUp();
	break;

	case "_":	// Pen down
	    $turtle->PenDown();
	break;

	case "[":	// Push
	    $turtle->Push();
	break;

	case "]":	// Pop
	    $turtle->Pop();
	break;
	
	case "<":	// Subiter
	    $deep++;
	break;
	
	case ">":	// End subiter
	    $deep--;
	break;

	case ".":	// Dot
	    $turtle->Dot();
	break;

	case "*":	// Big dot
	    $turtle->BigDot();
	break;
    }
}


if (!$debug)
    imagepng($im);

imagedestroy($im);

?>