<h1>Help</h1>
<p>
<b>WWW L-System Explorer</b> is simple WWW interpreter of L-systems
written in PHP. The package contains universal turtle graphic
class together with bunch of other scripts and is presented under 
<a href="http://www.gnu.org/licenses/gpl.html" class="help" target="_blank">GNU General Public License</a>.
In case you modify this software or use parts of it in some of your projects,
please let me know so I've got at least some feedback.
</p>

<p>
For more information about L-Systems, please visit
<a href="http://en.wikipedia.org/wiki/L-System" class="help" target="_blank">Wikipedia article</a>.
Please notice, that syntax of L-Systems differ among implementations, it is necessary
to program this one according to rules
<a href="#rules" class="help">described below</a>.

</p>
<hr>
<a name="width"></a><h3>Width</h3>
<p>
Width of resulting picture in pixels.
</p><hr>
<a name="height"></a><h3>Height</h3>
<p>
Height of resulting picture in pixels.
</p><hr>
<a name="x"></a><h3>Center X</h3>
<p>
Horizontal position of the center of drawing.
</p><hr>
<a name="y"></a><h3>Center Y</h3>
<p>
Vertical position of the center of drawing.
</p><hr>
<a name="countxy"></a><h3>Count center</h3>
<p>
In case this field is checked the drawing is processed
twice. In first pass the boundaries are estimated
and the center of drawing is counted.
This value is filled in fields presented above and
the main processing (drawing) is run. After that the
field is unchecked because it slows down the whole system
and the center of drawing is very often the same
between two user inputs.
</p><hr>
<a name="iter"></a><h3>Iterations</h3>
<p>
Number of iterations.
</p><hr>

<a name="step"></a><h3>Step</h3>
<p>
Basic step in pixels.
</p><hr>

<a name="angle"></a><h3>Angle</h3>
<p>
Basic angle in degrees.
</p><hr>

<a name="d_step"></a><h3>-&Delta; step</h3>
<p>
In case there are iteration marks in resulting string (ie. commands <b>&lt;</b> or <b>&gt;</b>),
the basic step is decreased by number of percents in this field.
With next iteration mark the step is decreased again but the measure is taken
from current (already decreased) basic step. This can be handy for defining
biological structures as trees and bushes.
</p><hr>

<a name="d_angle"></a><h3>-&Delta; angle</h3>
<p>
In case there are iteration marks in resulting string (ie. commands <b>&lt;</b> or <b>&gt;</b>),
the basic angle is decreased by number of percents in this field.
With next iteration mark the angle is decreased again but the measure is taken
from current (already decreased) basic angle.
</p><hr>

<a name="bgcol"></a><h3>Background color</h3>
<p>
Hexadecimal RGB triplet of drawing's background color (ie. <code>FFAA0</code> for orange, <code>00FF00</code> for green, etc.).
</p><hr>

<a name="pencol1"></a><h3>Pen color</h3>
<p>
Hexadecimal RGB triplet of initial pen color (ie. <code>FF000</code> for red, <code>0000FF</code> for blue, etc.).
</p><hr>

<a name="pencol2"></a><h3>Target color</h3>
<p>
In case there are iteration marks in resulting string (ie. commands <b>&lt;</b> or <b>&gt;</b>),
the pen color is changed towards this target color every iteration step using linear
interpolation of RGB components.
</p><hr>

<a name="dotcol"></a><h3>Dot color</h3>
<p>
Hexadecimal RGB triplet of dots' color (ie. <code>FFFF00</code> for yellow, <code>FF00FF</code> for magenta, etc.)
which are drawn using <b>.</b> and <b>*</b> commands.
</p><hr>

<a name="presets"></a><h3>Presets</h3>
<p>
Some setup examples. For more of those please visit <a href="http://www.246.dk/lsystems.html" class="help" target="_blank">this</a>
page. Don't forget the grammar is a bit different so you have to change some expressions.
</p><hr>

<a name="root"></a><h3>Root</h3>
<p>
Initial string for iteration. Don't forget to begin with "<b>_</b>", 
which drops the turtle down. (so initial state is with turtle up) Otherwise the drawing won't be visible because
the pen (turtle) will be in the air all the time.
</p><hr>

<a name="rules"></a><h3>Rules</h3>
<p>
Grammar rules are defined here. Every rule is in form of
</p>
<center><code>X=&lt;string&gt;;</code></center><Br>
<p>
<code>X</code> can be only <b>one</b> character long, <code>&lt;string&gt;</code> can
be of arbitary length. Rules are delimited with semicolon "<code>;</code>"
which is optional after last rule.
Reserved characters (which cannot stand on the left side of the expression) 
are <b>equal sign</b> (=) and <b>semicolon</b> (;). All defined commands
for the turtle are presented below. They <b>can</b> be derived by rules - ie. they
can stand on the left side of expressions.
</p>

<table>
<tr><td class="big">F</td><td>moves turtle forward</td>
<tr><td class="big">B</td><td>moves turtle backward</td>
<tr><td class="big">R</td><td>moves turtle forward <i>randomize(0,step)</i></td>
<tr><td class="big">+</td><td>rotates turtle clockwise</td>
<tr><td class="big">-</td><td>rotates turtle anti-clockwise</td>
<tr><td class="big">f</td><td>moves turtle halfstep forward</td>
<tr><td class="big">b</td><td>moves turtle halfstep backward</td>
<tr><td class="big">/</td><td>rotates turtle halfangle clockwise</td>
<tr><td class="big">\</td><td>rotates turtle halfangle anti-clockwise</td>
<tr><td class="big">[</td><td>pushes position and rotation of turtle to stack</td>
<tr><td class="big">]</td><td>pops position and rotation of turtle from stack</td>
<tr><td class="big">^</td><td>picks turtle up</td>
<tr><td class="big">_</td><td>drops turtle down</td>
<tr><td class="big">&lt;</td><td>one iteration level down</td>
<tr><td class="big">&gt;</td><td>one iteration level up</td>
<tr><td class="big">.</td><td>draws a small dot</td>
<tr><td class="big">*</td><td>draws a big dot</td>
</table>

<p align=right>
<a href="http://validator.w3.org/check?uri=referer">
<img src="http://www.w3.org/Icons/valid-html401"
     alt="Valid HTML 4.01 Transitional" height="31" width="88" border=0></a>
</p>
